@@ -154,11 +154,53 @@ class Importer:
         else:
             return 1
 
+    def __config_ln_firefox(self):
+        if not os.path.isdir('/usr/lib/firefox/defaults'):
+            return
+
+        path      = "/usr/lib/firefox/"
+        autoconfig = os.path.join(path, 'defaults/pref/autoconfig.js')
+        proxconfig = os.path.join(path, 'proxverter.cfg')
+
+        fl = open(autoconfig, 'w')
+        fl.write('pref("general.config.filename", "proxverter.cfg");\n')
+        fl.write('pref("general.config.obscure_value", 0);\n')
+        fl.close()
+
+        fl = open(proxconfig, 'w')
+        fl.write('//\n')
+        fl.write('lockPref("network.proxy.type", 5);\n')
+        fl.write('lockPref("security.enterprise_roots.enabled", true);\n')
+        fl.close()
+
     def __import_linux(self):
-        shutil.copy(self.home_paths['certname'], f"/usr/local/share/ca-certificates/proxverter.pem")
-        shutil.copy(self.home_paths['certname'], f"/etc/ssl/certs/proxverter.pem")
-        rtval = subprocess.call("update-ca-certificates", shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        return rtval
+        globals()["pwd"] = __import__("pwd")
+        shutil.copy(self.home_paths['certname'], f"/usr/local/share/ca-certificates/proxverter.crt")
+        subprocess.call("chmod 777 /usr/local/share/ca-certificates/proxverter.crt", shell=True)
+        subprocess.call("update-ca-certificates", shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+
+        users = pwd.getpwall()
+        for user in users:
+            if hasattr(user, 'pw_name') and hasattr(user, 'pw_shell'):
+                if (user.pw_shell == "/bin/bash" or user.pw_shell == "bin/sh"):
+
+                    ## For Chrome
+                    if not os.path.isdir(os.path.join(user.pw_dir, ".pki/nssdb")):
+                        os.makedirs(os.path.join(user.pw_dir, ".pki/nssdb"))
+                    subprocess.call(f'certutil -d sql:{user.pw_dir}/.pki/nssdb -A -t "C,C,C" -n proxverter -i {self.home_paths["certname"]}', shell=True)
+
+                    ## For Firefox
+                    if os.path.isdir(os.path.join(user.pw_dir, ".mozilla/firefox")):
+                        dirm = ""
+                        for dd in os.listdir(os.path.join(user.pw_dir, ".mozilla/firefox")):
+                            if dd.endswith("-release"):
+                                dirm = dd
+                                break
+
+                        if dirm:
+                            subprocess.call(f'certutil -d "sql:{user.pw_dir}/.mozilla/firefox/{dirm}" -A -t "C,C,C" -n proxverter -i {self.home_paths["certname"]}', shell=True)
+
+        return 0
 
     def cimport(self):
         plat = platform.system().lower()
@@ -168,6 +210,7 @@ class Importer:
             return rtval
         elif plat == "linux":
             rtval = self.__import_linux()
+            self.__config_ln_firefox()
             return rtval
         elif plat == "macos":
             pass
